"""Tests for pytest-services plugin."""
import os.path
import socket

import pylibmc
import MySQLdb


def test_memcached(request, memcached, memcached_socket):
    """Test memcached service."""
    mc = pylibmc.Client([memcached_socket])
    mc.set('some', 1)
    assert mc.get('some') == 1

    # check memcached cleaner
    request.getfixturevalue('memcached_clean')
    assert mc.get('some') is None


def test_mysql(mysql, mysql_connection, mysql_socket):
    """Test mysql service."""
    conn = MySQLdb.connect(user='root', unix_socket=mysql_socket)
    assert conn


def test_xvfb(xvfb, xvfb_display):
    """Test xvfb service."""
    socket.create_connection(('127.0.0.1', 6000 + xvfb_display))


def test_port_getter(port_getter):
    """Test port getter utility."""
    port1 = port_getter()
    sock1 = socket.socket(socket.AF_INET)
    sock1.bind(('127.0.0.1', port1))
    assert port1
    port2 = port_getter()
    sock2 = socket.socket(socket.AF_INET)
    sock2.bind(('127.0.0.1', port2))
    assert port2
    assert port1 != port2


def test_display_getter(display_getter):
    """Test display getter utility."""
    display1 = display_getter()
    assert display1
    display2 = display_getter()
    assert display2
    assert display1 != display2


def test_temp_dir(temp_dir):
    """Test temp dir directory."""
    assert os.path.isdir(temp_dir)



"""Setuptools entry point."""
import codecs
import os
import sys
import re

from setuptools import setup

dirname = os.path.dirname(__file__)

long_description = (
    codecs.open(os.path.join(dirname, 'README.rst'), encoding='utf-8').read() + '\n' +
    codecs.open(os.path.join(dirname, 'AUTHORS.rst'), encoding='utf-8').read() + '\n' +
    codecs.open(os.path.join(dirname, 'CHANGES.rst'), encoding='utf-8').read()
)

install_requires = [
    'requests',
    'psutil',
    'pytest',
    'zc.lockfile >= 2.0',
]

PY2 = sys.version_info[0] < 3

if PY2:
    install_requires.append('subprocess32')

with codecs.open(os.path.join(dirname, "pytest_services", "__init__.py"), encoding="utf-8") as fd:
    VERSION = re.compile(r".*__version__ = ['\"](.*?)['\"]", re.S).match(fd.read()).group(1)


setup(
    name='pytest-services',
    description='Services plugin for pytest testing framework',
    long_description=long_description,
    author='Anatoly Bubenkov, Paylogic International and others',
    license='MIT license',
    author_email='bubenkoff@gmail.com',
    version=VERSION,
    url='https://github.com/pytest-dev/pytest-services',
    install_requires=install_requires,
    extras={
        'memcached': ['pylibmc'],
    },
    classifiers=[
        'Development Status :: 6 - Mature',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: MacOS :: MacOS X',
        'Topic :: Software Development :: Testing',
        'Topic :: Software Development :: Libraries',
        'Topic :: Utilities',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ] + [('Programming Language :: Python :: %s' % x) for x in '2.7 3.4 3.5 3.6 3.7'.split()],
    tests_require=['tox'],
    entry_points={'pytest11': [
        'pytest-services=pytest_services.plugin',
    ]},
    packages=['pytest_services'],
)
